@@ -10,7 +10,7 @@ from .retry import retry
 
 async def get_job(session):
     '''
-    get the job from the queue
+    Get the job from the queue.
     '''
     next_job = None
 
@@ -19,8 +19,7 @@ async def get_job(session):
             next_job = await response.json()
         log.info(next_job)
     except Exception as err:  # pylint: disable=broad-except
-        log.error(
-            f"Error while getting job: {err}")
+        log.error(f"Error while getting job: {err}")
 
     return next_job
 
@@ -29,8 +28,7 @@ def run_job(handler, job):
     '''
     run the handler and format the return
     '''
-    log.info(
-        f"Started working on {job['id']} at {time.time()} UTC")
+    log.info(f"Started working on {job['id']} at {time.time()} UTC")
 
     try:
         job_output = handler(job)
@@ -39,21 +37,20 @@ def run_job(handler, job):
             return {
                 "error": job_output['error']
             }
+
         return {
             "output": job_output
         }
 
     except Exception as err:    # pylint: disable=broad-except
-        log.error(
-            f"Error while running job {job['id']}: {err}")
+        log.error(f"Error while running job {job['id']}: {err}")
 
         return {
             "error": str(err)
         }
 
     finally:
-        log.info(
-            f"Finished working on {job['id']} at {time.time()} UTC")
+        log.info(f"Finished working on {job['id']} at {time.time()} UTC")
 
 
 @retry(max_attempts=3, base_delay=1, max_delay=3)
@@ -75,10 +72,9 @@ async def retry_send_result(session, job_data):
 
 async def send_result(session, job_data, job):
     '''
-    try except wrapper
+    Return the job results.
     '''
     try:
         await retry_send_result(session, job_data)
     except Exception as err:  # pylint: disable=broad-except
-        log.error(
-            f"Error while returning job result {job['id']}: {err}")
+        log.error(f"Error while returning job result {job['id']}: {err}")
