@@ -3,6 +3,10 @@
 import os
 from dotenv import load_dotenv
 
+LOG_LEVEL_ERROR = 'ERROR'
+LOG_LEVEL_WARN = 'WARNING'
+LOG_LEVEL_INFO = 'INFO'
+LOG_LEVEL_DEBUG = 'DEBUG'
 
 env_path = os.getcwd() + '/.env'
 load_dotenv(env_path)  # Load environment variables
@@ -30,12 +34,38 @@ def log_secret(secret_name, secret, level='INFO'):
         log(f"{secret_name}: {redacted_secret}", level)
 
 
+def error(message):
+    '''
+    error log
+    '''
+    log(message, LOG_LEVEL_ERROR)
+
+
+def warn(message):
+    '''
+    warn log
+    '''
+    log(message, LOG_LEVEL_WARN)
+
+
+def info(message):
+    '''
+    info log
+    '''
+    log(message, LOG_LEVEL_INFO)
+
+
+def debug(message):
+    '''
+    debug log
+    '''
+    log(message, LOG_LEVEL_DEBUG)
+
+
 log('Logging module loaded')
 
 log_secret('RUNPOD_AI_API_KEY', os.environ.get('RUNPOD_AI_API_KEY', None))
-log_secret('RUNPOD_WEBHOOK_GET_JOB', os.environ.get('RUNPOD_WEBHOOK_GET_JOB', None))
-log_secret('RUNPOD_WEBHOOK_POST_OUTPUT', os.environ.get('RUNPOD_WEBHOOK_POST_OUTPUT', None))
-
-# log_secret('BUCKET_ENDPOINT_URL', os.environ.get('BUCKET_ENDPOINT_URL', None))
-# log_secret('BUCKET_ACCESS_KEY_ID', os.environ.get('BUCKET_ACCESS_KEY_ID', None))
-# log_secret('BUCKET_SECRET_ACCESS_KEY', os.environ.get('BUCKET_SECRET_ACCESS_KEY', None))
+log_secret('RUNPOD_WEBHOOK_GET_JOB', os.environ.get(
+    'RUNPOD_WEBHOOK_GET_JOB', None))
+log_secret('RUNPOD_WEBHOOK_POST_OUTPUT', os.environ.get(
+    'RUNPOD_WEBHOOK_POST_OUTPUT', None))
